==> luna_analytics_manager-0.0.14.tar.gz: luna_analytics_manager-0.0.14/luna_analytics_manager/templates/sdk.py <==
from typing import Any, Generic, SupportsIndex, TypeAlias

import attr
import numpy as np
from lunavl.sdk.errors.errors import ErrorInfo
from lunavl.sdk.image_utils.image import VLImage
from sdk_loop.estimators.engine import SDKEngine
from sdk_loop.tasks.task import DeepfakeParams, LivenessV1Params

from luna_analytics_manager.manager import AnalyticsManager

from .models import CommonParams, CommonTargets, FrequencyParams, TargetRootType


@attr.dataclass(slots=True)
class SDKCore:
    """SDK stub."""

    engine: SDKEngine

    livenessV1Settings: LivenessV1Params = LivenessV1Params(scoreThreshold=0.5)
    deepfakeSettings: DeepfakeParams = DeepfakeParams(scoreThreshold=0.5)


class SDKAnalyticsTargets(CommonTargets, Generic[TargetRootType]):
    """Base analytics targets stub."""

    @classmethod
    def load(cls, obj: Any, *args, **kwargs):
        return cls.model_validate(obj, *args, **kwargs) if obj is not None else cls()


class SDKAnalyticsParams(CommonParams):
    """Base analytics parameters stub."""

    @classmethod
    def load(cls, obj: Any, *args, **kwargs):
        return cls.model_validate(obj, *args, **kwargs) if obj is not None else cls()


@attr.dataclass(slots=True)
class SDKAnalyticsCtx:
    """Base analytics context stub."""

    sdk: SDKCore
    params: SDKAnalyticsParams
    targets: SDKAnalyticsTargets

    aggregated: Any
    error: ErrorInfo | None = attr.field(init=False)

    accumulating: bool = True

    def __attrs_post_init__(self):
        self.error = None


@attr.dataclass(slots=True)
class SDKFrameCtx:
    """Base frame context stub."""

    image: VLImage
    number: int
    timestamp: float
    lastFrame: bool
    error: ErrorInfo | None = attr.field(init=False)
    processed: Any

    def __attrs_post_init__(self):
        self.error = None


class FrameRateChecker:
    """Frame rate checker."""

    def __init__(self, config: FrequencyParams | None):
        self.config = config
        self.skipUntilTs = 0
        self.lastFramePassed = 0

    def checkFrameSkip(self, frameCtx: SDKFrameCtx) -> bool:
        """Handle frame skipping."""

        if self.config is None:
            return False

        match self.config.unit:
            case "frame":
                if frameCtx.number == 1 or frameCtx.number >= self.lastFramePassed + self.config.period:
                    self.lastFramePassed = frameCtx.number
                    return False
            case "second":
                if frameCtx.number == 1 or frameCtx.timestamp >= self.skipUntilTs:
                    self.skipUntilTs = frameCtx.timestamp + self.config.period
                    return False

        if frameCtx.lastFrame:
            return False

        return True


SDKFrameBuffer: TypeAlias = np.ndarray[SupportsIndex, np.dtype[np.uint8]] | VLImage


class SDKAnalyticsManager(AnalyticsManager[SDKFrameBuffer, VLImage]):
    """Base analytics manager stub."""

    def loadFrame(self, decoderFrame: SDKFrameBuffer) -> VLImage:
        if isinstance(decoderFrame, np.ndarray):
            return VLImage.fromNumpyArray(decoderFrame)
        return decoderFrame

    def getRater(self, ctx: SDKAnalyticsCtx) -> FrameRateChecker:
        config = getattr(ctx, "getAnalyticsRate", lambda: None)()
        return FrameRateChecker(config)

==> luna_analytics_manager-0.0.27.tar.gz: luna_analytics_manager-0.0.27/luna_analytics_manager/templates/sdk.py <==
from typing import Any, Generic, TypeAlias

import attr
import numpy as np
from lunavl.sdk.errors.errors import ErrorInfo
from lunavl.sdk.image_utils.image import VLImage
from sdk_loop.estimators.engine import SDKEngine
from sdk_loop.tasks.task import DeepfakeParams, LivenessV1Params

from luna_analytics_manager.manager import AnalyticsManager

from .models import CommonParams, CommonTargets, FrequencyParams, TargetRootType


@attr.dataclass(slots=True)
class SDKCore:
    """SDK stub."""

    engine: SDKEngine

    livenessV1Settings: LivenessV1Params = LivenessV1Params(scoreThreshold=0.5)
    deepfakeSettings: DeepfakeParams = DeepfakeParams(scoreThreshold=0.5)


class SDKAnalyticsTargets(CommonTargets, Generic[TargetRootType]):
    """Base analytics targets stub."""

    @classmethod
    def load(cls, obj: Any, *args, **kwargs):
        return cls.model_validate(obj, *args, **kwargs) if obj is not None else cls()


class SDKAnalyticsParams(CommonParams):
    """Base analytics parameters stub."""

    @classmethod
    def load(cls, obj: Any, *args, **kwargs):
        return cls.model_validate(obj, *args, **kwargs) if obj is not None else cls()


@attr.dataclass(slots=True)
class SDKAnalyticsCtx:
    """Base analytics context stub."""

    sdk: SDKCore
    params: SDKAnalyticsParams
    targets: SDKAnalyticsTargets

    aggregated: Any
    error: ErrorInfo | None = attr.field(init=False)

    accumulating: bool = True

    def __attrs_post_init__(self):
        self.error = None


@attr.dataclass(slots=True)
class SDKFrameCtx:
    """Base frame context stub."""

    image: VLImage
    number: int
    timestamp: float
    lastFrame: bool
    error: ErrorInfo | None = attr.field(init=False)
    processed: Any

    def __attrs_post_init__(self):
        self.error = None


class FrameRateChecker:
    """Frame rate checker."""

    def __init__(self, config: FrequencyParams | None):
        self.config = config
        self.skipUntilTs = 0
        self.lastFramePassed = 0

    def checkFrameSkip(self, frameCtx: SDKFrameCtx) -> bool:
        """Handle frame skipping."""

        if self.config is None:
            return False

        match self.config.unit:
            case "frame":
                if frameCtx.number == 1 or frameCtx.number >= self.lastFramePassed + self.config.period:
                    self.lastFramePassed = frameCtx.number
                    return False
            case "second":
                if frameCtx.number == 1 or frameCtx.timestamp >= self.skipUntilTs:
                    self.skipUntilTs = frameCtx.timestamp + self.config.period
                    return False

        if frameCtx.lastFrame:
            return False

        return True


SDKFrameBuffer: TypeAlias = np.typing.ArrayLike | VLImage


class SDKAnalyticsManager(AnalyticsManager[SDKFrameBuffer, VLImage]):
    """Base analytics manager stub."""

    def loadFrame(self, decoderFrame: SDKFrameBuffer) -> VLImage:
        if isinstance(decoderFrame, np.ndarray):
            return VLImage.fromNumpyArray(decoderFrame)
        return decoderFrame

    def getRater(self, ctx: SDKAnalyticsCtx) -> FrameRateChecker:
        config = getattr(ctx, "getAnalyticsRate", lambda: None)()
        return FrameRateChecker(config)
